@@ -23,6 +23,22 @@ func (config *UserConfig) Validate() error {
 		[]string{"none", "onlyMainBranches", "allBranches"}); err != nil {
 		return err
 	}
+	if err := validateEnum("git.localBranchSortOrder", config.Git.LocalBranchSortOrder,
+		[]string{"date", "recency", "alphabetical"}); err != nil {
+		return err
+	}
+	if err := validateEnum("git.remoteBranchSortOrder", config.Git.RemoteBranchSortOrder,
+		[]string{"date", "alphabetical"}); err != nil {
+		return err
+	}
+	if err := validateEnum("git.log.order", config.Git.Log.Order,
+		[]string{"date-order", "author-date-order", "topo-order", "default"}); err != nil {
+		return err
+	}
+	if err := validateEnum("git.log.showGraph", config.Git.Log.ShowGraph,
+		[]string{"always", "never", "when-maximised"}); err != nil {
+		return err
+	}
 	if err := validateKeybindings(config.Keybinding); err != nil {
 		return err
 	}
@@ -56,7 +72,7 @@ func validateKeybindingsRecurse(path string, node any) error {
 			}
 		}
 	} else if value.Kind() == reflect.Slice {
-		for i := 0; i < value.Len(); i++ {
+		for i := range value.Len() {
 			if err := validateKeybindingsRecurse(
 				fmt.Sprintf("%s[%d]", path, i), value.Index(i).Interface()); err != nil {
 				return err
